@@ -4,8 +4,8 @@ Test management command to reapply failed tasks.
 
 from collections import Counter
 from datetime import datetime
+from unittest import mock
 
-import mock
 import pytest
 
 from django.core.management import call_command
@@ -28,24 +28,24 @@ def failed_tasks():
     return [
         models.FailedTask.objects.create(
             task_name=tasks.fallible_task.name,
-            task_id=u'fail_again',
+            task_id='fail_again',
             args=[],
             kwargs={"error_message": "Err, yo!"},
-            exc=u'UhOhError().',
+            exc='UhOhError().',
         ),
         models.FailedTask.objects.create(
             task_name=tasks.fallible_task.name,
-            task_id=u'will_succeed',
+            task_id='will_succeed',
             args=[],
             kwargs={},
-            exc=u'NetworkErrorMaybe?()',
+            exc='NetworkErrorMaybe?()',
         ),
         models.FailedTask.objects.create(
             task_name=tasks.passing_task.name,
-            task_id=u'other_task',
+            task_id='other_task',
             args=[],
             kwargs={},
-            exc=u'RaceCondition()',
+            exc='RaceCondition()',
         ),
     ]
 
@@ -53,19 +53,19 @@ def failed_tasks():
 @pytest.mark.django_db
 @pytest.mark.usefixtures('failed_tasks')
 def test_call_command():
-    call_command(u'reapply_tasks')
-    assert_unresolved(models.FailedTask.objects.get(task_id=u'fail_again'))
-    assert_resolved(models.FailedTask.objects.get(task_id=u'will_succeed'))
-    assert_resolved(models.FailedTask.objects.get(task_id=u'other_task'))
+    call_command('reapply_tasks')
+    assert_unresolved(models.FailedTask.objects.get(task_id='fail_again'))
+    assert_resolved(models.FailedTask.objects.get(task_id='will_succeed'))
+    assert_resolved(models.FailedTask.objects.get(task_id='other_task'))
 
 
 @pytest.mark.django_db
 @pytest.mark.usefixtures('failed_tasks')
 def test_call_command_with_specified_task():
-    call_command(u'reapply_tasks', u'--task-name={}'.format(tasks.fallible_task.name))
-    assert_unresolved(models.FailedTask.objects.get(task_id=u'fail_again'))
-    assert_resolved(models.FailedTask.objects.get(task_id=u'will_succeed'))
-    assert_unresolved(models.FailedTask.objects.get(task_id=u'other_task'))
+    call_command('reapply_tasks', f'--task-name={tasks.fallible_task.name}')
+    assert_unresolved(models.FailedTask.objects.get(task_id='fail_again'))
+    assert_resolved(models.FailedTask.objects.get(task_id='will_succeed'))
+    assert_unresolved(models.FailedTask.objects.get(task_id='other_task'))
 
 
 @pytest.mark.django_db
@@ -73,19 +73,19 @@ def test_call_command_with_specified_task():
 def test_duplicate_tasks():
     models.FailedTask.objects.create(
         task_name=tasks.fallible_task.name,
-        task_id=u'will_succeed',
+        task_id='will_succeed',
         args=[],
         kwargs={},
-        exc=u'AlsoThisOtherError()',
+        exc='AlsoThisOtherError()',
     )
     # Verify that only one task got run for this task_id.
     # pylint: disable=no-member
-    with mock.patch.object(tasks.fallible_task, u'apply_async', wraps=tasks.fallible_task.apply_async) as mock_apply:
-        call_command(u'reapply_tasks')
-        task_id_counts = Counter(call[2][u'task_id'] for call in mock_apply.mock_calls)
-        assert task_id_counts[u'will_succeed'] == 1
+    with mock.patch.object(tasks.fallible_task, 'apply_async', wraps=tasks.fallible_task.apply_async) as mock_apply:
+        call_command('reapply_tasks')
+        task_id_counts = Counter(call[2]['task_id'] for call in mock_apply.mock_calls)
+        assert task_id_counts['will_succeed'] == 1
     # Verify that both tasks matching that task_id are resolved.
-    will_succeed_tasks = models.FailedTask.objects.filter(task_id=u'will_succeed').all()
+    will_succeed_tasks = models.FailedTask.objects.filter(task_id='will_succeed').all()
     assert len(will_succeed_tasks) == 2
     for task_object in will_succeed_tasks:
         assert_resolved(task_object)
